use std::io;

use time::{format_description, OffsetDateTime};

#[derive(Debug)]
#[allow(dead_code)]
pub struct Error {
    msg: String,
}

impl Error {
    pub fn new(msg: &str) -> Self {
        Self { msg: msg.into() }
    }
}

impl From<ureq::Error> for Error {
    fn from(value: ureq::Error) -> Self {
        Self {
            msg: value.to_string(),
        }
    }
}
impl From<io::Error> for Error {
    fn from(value: io::Error) -> Self {
        Self {
            msg: value.to_string(),
        }
    }
}
impl From<serde_json::Error> for Error {
    fn from(value: serde_json::Error) -> Self {
        Self {
            msg: value.to_string(),
        }
    }
}
impl From<toml::de::Error> for Error {
    fn from(value: toml::de::Error) -> Self {
        Self {
            msg: value.to_string(),
        }
    }
}

impl From<roxmltree::Error> for Error {
    fn from(value: roxmltree::Error) -> Self {
        Self {
            msg: value.to_string(),
        }
    }
}

/// Returns the current date in YYYY-MM-DD format. Needed for RIS API query to get current version of the overview.
pub(crate) fn current_date() -> String {
    let local_date = OffsetDateTime::now_utc();
    let format = format_description::parse("[year]-[month]-[day]").unwrap(); //unwrap okay, supplied format is fine
    local_date.format(&format).expect("Failed to format date")
}
